Attribute VB_Name = "GraphDemos"
Option Explicit
Option Compare Text

'======================================================================
'This module contains all the procedures for the various Graph demos
'By Encore Consulting:  www.encoreconsulting.com.au
'======================================================================

Public Sub Demo1(ecGraph1 As ecGraph)
  '"No frills" simple x-y graph
  Dim i, X As Double, Y As Double
  With ecGraph1
    Call .Reset 'Always call "Reset" first to clear the page
    
    'Start a new graph on the page..
    Call .NewGraph("No-frills simple x-y graph")
    
    'Start a new data set on the graph, and add random points..
    Call .NewDataSet("Data 1")
    For i = 1 To 9
      X = 2 * i
      Y = Sqr(i) - Rnd(i) / 3
      Call .AddDataPoint(X, Y)
    Next i
    
    'Second data set for this graph
    Call .NewDataSet("Data 2")
    For i = 2 To 18
      X = i: Y = Log(i) / 2 - Rnd / 4
      Call .AddDataPoint(X, Y)
    Next i
    
    Call .Refresh 'Always end with "Refresh"
  End With
End Sub

Public Sub Demo2(ecGraph1 As ecGraph)
  '2D Bar Graph, with colors
  Dim Font$, i, X As Double, Y As Double
  With ecGraph1
    Call .Reset 'Always call "Reset" first to clear the page
    
    'Start a new graph on the page..
    Call .NewGraph("2D Bar Graph")
    Call .GraphTitleStyle(, "Font=Times New Roman|18|bold", ecBrown, -8, -12)
    Call .BorderStyle(ecCadetBlue, ecLightCyan, 90)
    Call .AxisStyle(ecBlack, 2)  'set x-axis line thickness to 2
    Font$ = "Font=Arial|9|bold|italic"
    Call .AxisTitleStyle("Item category", Font$, ecDarkBlue)
    Call .AxisLabelStyle(Font$, ecDarkBlue)
    
    Call .SelectYaxis 'select the y-axis.
    Call .AxisStyle(ecBlack, 2)  'set x-axis line thickness to 2
    Call .AxisTitleStyle("Sales frequency", Font$, ecDarkBlue, -3)
    Call .AxisLabelStyle(Font$, ecDarkBlue, -1)
    Call .LegendTableStyle(Font$, ecBlack, 12, 16, , 0, , , , , , True)
    
    'Start a new data set on the graph, and add random points..
    Call .NewDataSet("  Data 1")
    Call .SymbolStyle(1, 5, ecGold, ecDarkBlue, 2, False, 1.5, True) '2D bar, width 5mm
    For i = 1 To 9
      X = 2 * i
      Y = Sqr(i) + 1 + Rnd(i) / 3
      Call .AddDataPoint(X, Y)
    Next i
    
    'Start a new data set on the graph, and add random points..
    Call .NewDataSet("  Data 2")
    Call .SymbolStyle(1, 5, , , , , -1.5, True)     '2D bar, width 5mm
    For i = 1 To 9
      X = 2 * i
      Y = Sqr(i) - Rnd(i) / 3
      Call .AddDataPoint(X, Y)
    Next i
    
    Call .PlotAreaColors(ecBlue, ecLightBlue, 90)
    Call .Refresh 'Always end with "Refresh"
  End With
End Sub

Public Sub Demo3(ecGraph1 As ecGraph)
  'Bar Graph, 3D bars, colors and styles
  Dim i, X As Double, Y As Double
  With ecGraph1
    Call .Reset 'Always call "Reset" first to clear the page
    
    'Start a new graph on the page..
    Call .NewGraph("Bar Graph, 3D bars, colors and styles")
    Call .BorderStyle(ecCadetBlue, ecLightCyan, 0, 1, , , -1, 7, -1, -1)
    Call .LegendTableStyle(, , 21, 25, , 0, , , , , , True)
    
    'Start a new data set on the graph, and add random points..
    Call .NewDataSet("Data 1")
    Call .SymbolStyle(1, 7, ecLightCyan, 6750208, 1, True) '3D bar, width 5mm
    For i = 1 To 9
      X = 2 * i
      Y = Sqr(i) - Rnd(i) / 2
      Call .AddDataPoint(X, Y)
    Next i
    
    Call .PlotAreaColors(ecBlack, ecBlue, 120, , -6)
    Call .Refresh 'Always end with "Refresh"
  End With
End Sub

Public Sub Demo4(ecGraph1 As ecGraph)
  'Multiple 3D Bar Graph, Text labels
  Dim i, X As Double, Y As Double
  With ecGraph1
    Call .Reset 'Always call "Reset" first to clear the page
    
    'Start a new graph on the page..
    Call .NewGraph("Multiple 3D Bar Graph, Text labels")
    Call .GraphTitleStyle(, "bold|16|italic", ecBlue, 15, -10)
    Call .BorderStyle(ecCadetBlue, ecLightCyan, 0, , , , 20, 7, -1, -1)
    Call .PlotAreaColors(ecBurlywood, ecLightCyan, 90)
    Call .LegendTableStyle(, , 15, 10, , 0, , , , , , True)
    Call .AxisStyle(, 3)
    Call .AxisLabelStyle("bold||11|", , -3, 0)
    Call .AxisTitleStyle(, "bold|11|", , 0, False)
    Call .AxisTickStyle(, , False, False, False)
    Call .AxisScaleStyle(0, 30, 6, 0, 2, ",Wombats,Koalas,Possums,Wallabies,Kangaroos")
    Call .SelectYaxis
    Call .AxisStyle(, 3)
    Call .AxisLabelStyle("bold||11|", , -1, 0)
    Call .AxisTitleStyle(, "bold|11|", , -4, False)
    Call .AxisScaleStyle(0, 5, 5, 0, 2, ",low,medium,high,very high")
    Call .AxisTickStyle(, , False, False, False)
    Call .AxisGridStyle(ecGray, , True, False)
    
    'Start a new data set on the graph, and add random points..
    Call .NewDataSet("Cuddly")
    Call .SymbolStyle(1, 5, ecLightBlue, 6750208, 1, True, -4.9, True) '3D bar, width 5mm
    For i = 1 To 5
      X = 5 * i
      Y = 2 + 2 * Rnd(i)
      Call .AddDataPoint(X, Y)
    Next i
    
    'Start a new data set on the graph, and add random points..
    Call .NewDataSet("Friendly")
    Call .SymbolStyle(1, 5, ecLightPink, ecMaroon, 1, True, 0, True)     '2D bar, width 5mm
    For i = 1 To 5
      X = 5 * i
      Y = 2 + 2 * Rnd(i)
      Call .AddDataPoint(X, Y)
    Next i
    
    'Start a new data set on the graph, and add random points..
    Call .NewDataSet("Cute")
    Call .SymbolStyle(1, 5, ecLightGreen, ecDarkGreen, 1, True, 4.9, True)     '2D bar, width 5mm
    For i = 1 To 5
      X = 5 * i
      Y = 2 + 2 * Rnd(i)
      Call .AddDataPoint(X, Y)
    Next i
    
    Call .Refresh 'Always end with "Refresh"
  End With
End Sub

Public Sub Demo5(ecGraph1 As ecGraph)
  'Stacked 3D Bar Graph, Text labels
  Dim i, X As Double, Y As Double
  With ecGraph1
    Call .Reset 'Always call "Reset" first to clear the page
    
    'Start a new graph on the page..
    Call .NewGraph("Stacked 3D Bar Graph, Text labels")
    Call .GraphTitleStyle(, "bold|16|italic", ecBlue, 15, -10)
    Call .BorderStyle(ecCadetBlue, ecLightCyan, 0, , , , 20, 7, -1, -1)
    Call .PlotAreaColors(ecBurlywood, ecLightCyan, 90)
    Call .LegendTableStyle(, , 2, 4, , 0, , , , , , True)
    Call .AxisStyle(, 3)
    Call .AxisLabelStyle("bold||11|", , -3, 0)
    Call .AxisTitleStyle(, "bold|11|", , 0, False)
    Call .AxisTickStyle(, , False, False, False)
    Call .AxisScaleStyle(0, 30, 6, 0, 2, ",Wombats,Koalas,Possums,Wallabies,Kangaroos")
    Call .SelectYaxis
    Call .AxisStyle(, 3)
    Call .AxisLabelStyle("bold||11|", , -1, 0)
    Call .AxisTitleStyle(, "bold|11|", , -4, False)
    Call .AxisScaleStyle(0, 12, 6, 0, 2, ",low,medium,high,very high")
    Call .AxisTickStyle(, , False, False, False)
    Call .AxisGridStyle(ecGray, , True, False)
    
    'Start a new data set on the graph, and add random points..
    Call .NewDataSet("A")
    Call .SymbolStyle(1, 7, 12431236, 9699328, 1, True, -3) '3D bar, width 5mm
    For i = 1 To 5
      X = 5 * i
      Y = 2 + 2 * Rnd(i)
      Call .AddDataPoint(X, Y)
    Next i
    
    'Start a new data set on the graph, and add random points..
    Call .NewDataSet("B")
    Call .SymbolStyle(1, 7, ecLightPink, ecMaroon, 1, True, -3, , True)     '2D bar, width 5mm
    For i = 1 To 5
      X = 5 * i
      Y = 2 + 2 * Rnd(i)
      Call .AddDataPoint(X, Y)
    Next i
    
    'Start a new data set on the graph, and add random points..
    Call .NewDataSet("C")
    Call .SymbolStyle(1, 7, ecLightGreen, ecDarkGreen, 1, True, -3, , True)     '2D bar, width 5mm
    For i = 1 To 5
      X = 5 * i
      Y = 2 + 2 * Rnd(i)
      Call .AddDataPoint(X, Y)
    Next i
    
    'Start a new data set on the graph, and add random points..
    Call .NewDataSet("D")
    Call .SymbolStyle(1, 7, ecGray, ecBlack, 1, True, 3.5) '3D bar, width 5mm
    For i = 1 To 5
      X = 5 * i
      Y = 2 + 2 * Rnd(i)
      Call .AddDataPoint(X, Y)
    Next i
    
    'Start a new data set on the graph, and add random points..
    Call .NewDataSet("E")
    Call .SymbolStyle(1, 7, 55295, 26007, 1, True, 3.5, , True)     '2D bar, width 5mm
    For i = 1 To 5
      X = 5 * i
      Y = 2 + 2 * Rnd(i)
      Call .AddDataPoint(X, Y)
    Next i
    
    'Start a new data set on the graph, and add random points..
    Call .NewDataSet("F")
    Call .SymbolStyle(1, 7, ecLightPink, ecDarkMagenta, 1, True, 3.5, , True)     '2D bar, width 5mm
    For i = 1 To 5
      X = 5 * i
      Y = 2 + 2 * Rnd(i)
      Call .AddDataPoint(X, Y)
    Next i
    
    Call .Refresh 'Always end with "Refresh"
  End With
End Sub


Public Sub Demo6(ecGraph1 As ecGraph)
  'Two data sets, grid lines, black background
  Dim i, Color As Long, X As Double, Y As Double
  Dim Symbol As Integer, SymbolSize As Single, Line As Integer, Legend$
  With ecGraph1
    Call .Reset 'Always call "Reset" first
    
    'Start the first graph...
    Call .NewGraph("Two data sets, grid lines, black background")
    Call .GraphTitleStyle(, , , , , False)
    Call .BorderStyle(ecDarkSeaGreen)
    Call .PlotAreaColors(ecBlack)
    Call .AxisGridStyle(ecGray, ecDarkGreen)
    Call .LegendTableStyle(, , 11, 8, , , ecLightGrey, ecLightGrey)
    Call .AxisLabelStyle("bold")
    Call .AxisTitleStyle("x-axis", "bold")
    Call .SelectYaxis 'select the y-axis before adjusting its style
    Call .AxisLabelStyle("bold", , -1)
    Call .AxisTitleStyle("y-axis", "bold", , -3)
    
    'First data set for this graph
    Call .NewDataSet("Data set 1")
    Call .DataLine(ecBlue, 2)
    Call .SymbolStyle(3, 3.5, ecBlue, ecYellow, 2)
    For i = 1 To 14
      X = 1.4 * i: Y = Sqr(i) + Rnd
      Call .AddDataPoint(X, Y)
    Next i
    
    'Second data set for this graph
    Call .NewDataSet("Data set 2")
    Call .SymbolStyle(3, 3.5, ecRed, ecYellow, 2)
    For i = 1 To 14
      X = 1.4 * i: Y = Sqr(i) - Rnd
      Call .AddDataPoint(X, Y)
    Next i
    
    Call .Refresh 'Always end with "Refresh"
  End With
End Sub

Public Sub Demo7(ecGraph1 As ecGraph)
  'Math function, Points with error bars
  Dim MathFunc$, i, Color As Long, X As Double, Y As Double
  Dim Symbol As Integer, SymbolSize As Single, Line As Integer, Legend$
  With ecGraph1
    Call .Reset 'Always call "Reset" first
    
    'Start the graph...
    Call .NewGraph("Math function, Points with error bars") ', 0, 20, -1, 1)
    Call .AxisScaleStyle(0, 20, 4, 5, 1)
    Call .PlotAreaColors(ecLightSalmon, ecMintCream)
    Call .BorderStyle(ecLightGreen, ecMintCream)
    Call .LegendTableStyle(, , 67, 70)
    
    Call .SelectYaxis 'select the y-axis.
    Call .AxisScaleStyle(-1, 1, 4, 5, 1)
    Call .AxisLabelStyle("", , -1, 0)
    
    'Add upper boundary line as a math function..
    MathFunc$ = "exp(-x/10)"
    Call .NewDataSet("upper boundary line", False)
    Call .AddMathFunc(MathFunc$, 0, 20)
    Call .DataLine(ecGreen)
    
    'Add lower boundary line as a math function..
    MathFunc$ = "-exp(-x/10)"
    Call .NewDataSet("lower boundary line", False)
    Call .AddMathFunc(MathFunc$, 0, 20)
    Call .DataLine(ecGreen)
    
    'Add some data points..
    Call .NewDataSet("Data set 2")
    Call .SymbolStyle(3, 1.6, ecRed, ecRed)
    .BarShadowColor = ecBrown '(use shadow color for error bar color)
    Call .DataLine(, , 0)
    For i = 1 To 30
      X = i / 1.6: Y = Sin(X) * Exp(-X / 10) + (Rnd - 0.5) / 5
      Call .AddDataPoint(X, Y, 0.08 * (1 + Rnd)) '(x,y,error bar height)
    Next i
    
    'Add a math function..
    MathFunc$ = "sin(x)*exp(-x/10)"
    Call .NewDataSet("y = " + MathFunc$, True)
    Call .AddMathFunc(MathFunc$, 0, 20)
    Call .DataLine(ecBlue, 2)
    
    'Add text..
    Call .NewDataSet("Text")
    Call .AddText("Place multi-line text on the graph..." + vbCrLf _
                + "*  select an area with the mouse to zoom in" + vbCrLf _
                + "*  when zoomed, use scroll bars bottom & right" + vbCrLf _
                + "*  right-click to unzoom" + vbCrLf _
                + "*  drag the legend table" + vbCrLf _
                + "*  adjust graph position and margins", _
                45, 97, 0, "", ecCrimson, 0, True)
    
    Call .Refresh 'Always end with "Refresh"
  End With
End Sub

Public Sub Demo8(ecGraph1 As ecGraph)
  'Two graphs on the Page
  Dim MathFunc$, S$, i, Color As Long, X As Double, Y As Double
  Dim Symbol As Integer, SymbolSize As Single, Line As Integer, Legend$
  With ecGraph1
    Call .Reset 'Always call "Reset" first
    
    Call .PageColors(ecCoral, ecBlanchedAlmond)
    'Start the first graph...
    Call .NewGraph("Graph 1")
    Call .GraphPosition(2, 2, 80, 50)
    Call .BorderStyle(ecHotPink, ecBlanchedAlmond, , , , , 12, 6, 6, 10)
    Call .PlotAreaColors(ecLightPink, ecBlanchedAlmond)
    
    'First data set for this graph
    Call .NewDataSet("Data 1")
    For i = 1 To 19
      X = i: Y = Sqr(i) + Rnd
      Call .AddDataPoint(X, Y)
    Next i
    
    'Second data set for this graph
    Call .NewDataSet("Data 1")
    For i = 1 To 19
      X = i: Y = Sqr(i) - Rnd
      Call .AddDataPoint(X, Y)
    Next i
    
    'Add text..
    Call .NewDataSet("Text")
    S$ = "Click to bring graph to front" + vbCrLf + "Drag graphs to reposition" + vbCrLf + "Drag legend table"
    Call .AddText(S$, 5, 95, 0, "bold", ecRed, 0, True)
    
    'Second graph...
    Call .NewGraph("Graph 2")
    Call .GraphPosition(30, 40, 65, 55)
    Call .BorderStyle(ecAquaMarine, ecBlanchedAlmond, , , , , 12, 5, 6, 10)
    Call .LegendTableStyle(, , 15, 10, ecGray, 0, , , , , , True)
    Call .PlotAreaColors(ecLightBlue, ecBlanchedAlmond)
    
    Call .NewDataSet("Data 1")
    Call .SymbolStyle(2)
    For i = 1 To 300
      X = i / 16: Y = Sqr(X) + Rnd
      Call .AddDataPoint(X, Y)
    Next i
    
    'Add a math function..
    MathFunc$ = "0.5 + sqr(x)"
    Call .NewDataSet("y = " + MathFunc$)
    Call .AddMathFunc(MathFunc$, 0, 20)
    
    'Add a math function..
    MathFunc$ = "2 + sin(x)"
    Call .NewDataSet("y = " + MathFunc$)
    Call .AddMathFunc(MathFunc$, 0, 20)
    
    'Add text..
    Call .NewDataSet("Text")
    S$ = "Click & drag to zoom in" + vbCrLf + "Use scroll bars when zooming" + vbCrLf + "Right click to unzoom"
    Call .AddText(S$, 45, 48, 0, "bold", vbRed, 0, True)
    
    Call .Refresh 'Always end with "Refresh"
  End With
End Sub

Public Sub Demo9(ecGraph1 As ecGraph)
  'Two graphs, transparent plot area
  Dim MathFunc$, S$, i, Color As Long, X As Double, Y As Double
  Dim Symbol As Integer, SymbolSize As Single, Line As Integer, Legend$
  With ecGraph1
    Call .Reset 'Always call "Reset" first
    
    Call .PageColors(ecBlueViolet, ecBlanchedAlmond, 200, , -5)
    'Start the first graph...
    Call .NewGraph("Two graphs, transparent plot area")
    Call .GraphPosition(2, 2, 80, 60)
    Call .BorderStyle(, , , , True, , 12, 6, 6, 10)
    Call .PlotAreaColors(, , , , , True)
    Call .LegendTableStyle(, , 15, 16, , , , , , , , True)
    
    'First data set for this graph
    Call .NewDataSet("Data 1")
    For i = 1 To 19
      X = i: Y = Sqr(i) + Rnd
      Call .AddDataPoint(X, Y)
    Next i
    
    'Second data set for this graph
    Call .NewDataSet("Data 1")
    For i = 1 To 19
      X = i: Y = Sqr(i) - Rnd
      Call .AddDataPoint(X, Y)
    Next i
    
    'Second graph...
    Call .NewGraph("Grab border area with mouse to move graphs")
    Call .GraphPosition(28, 40, 65, 55)
    Call .BorderStyle(, , , , True, , 12, 5, 6, 10)
    Call .LegendTableStyle(, , 60, 45, , 0, , , , , , True)
    Call .PlotAreaColors(, , , , , True)
    
    Call .NewDataSet("Data 1")
    Call .SymbolStyle(2)
    For i = 1 To 300
      X = i / 16: Y = Sqr(X) + Rnd
      Call .AddDataPoint(X, Y)
    Next i
    
    'Add a math function..
    MathFunc$ = "0.5 + sqr(x)"
    Call .NewDataSet("y = " + MathFunc$)
    Call .AddMathFunc(MathFunc$, 0, 20)
    
    'Add a math function..
    MathFunc$ = "2 + sin(x)"
    Call .NewDataSet("y = " + MathFunc$)
    Call .AddMathFunc(MathFunc$, 0, 20)
    
    Call .Refresh 'Always end with "Refresh"
  End With
End Sub

Public Sub Demo10(ecGraph1 As ecGraph)
  'Two y-axes, partial page
  Dim i, X As Double, Y As Double
  With ecGraph1
    Call .Reset 'Always call "Reset" first
    Call .NewGraph("Two y-axes, partial page") 'Start a new graph on the page
    Call .GraphPosition(10, 10, 80, 80)
    Call .PageColors(ecBlack, ecAliceBlue, 90)
    Call .BorderStyle(, , , , , , 22, 6, 6, 10)
    Call .LegendTableStyle(, , 19, 11)
    Call .PlotAreaColors(ecAquaMarine, ecBeige, 45, -0.3)
    Call .NewDataSet("Data 1, on y-axis #1") 'Start a new data set on the graph
    Call .DataLine(, , 2) 'dotted
    For i = 1 To 18 'Add some data points to the graph
      X = 100 + i
      Y = 100 + Sqr(i) + Rnd
      Call .AddDataPoint(X, Y)
    Next i
    
    Call .NewYAxis("y-Axis   #2")
    Call .NewDataSet("Data 2, on y-axis #2") 'Start a new data set on the graph
    Call .DataLine(, , 2) 'dotted
    For i = 1 To 18 'Add some data points to the graph
      X = 100 + i
      Y = 60 + Sqr(i) + Rnd
      Call .AddDataPoint(X, Y)
    Next i
    
    Call .Refresh 'Always end with "Refresh"
  End With
End Sub

Public Sub Demo11(ecGraph1 As ecGraph)
  'Multiple x- and y-axes
  Dim i, X As Double, Y As Double
  With ecGraph1
    Call .Reset 'Always call "Reset" first
    Call .NewGraph("Multiple x- and y-axes") 'Start a new graph on the page
    Call .AxisTitleStyle("First x-axis", , , 0)
    Call .BorderStyle(ecPurple, ecAliceBlue, 90)
    Call .PlotAreaColors(ecBrown, ecAliceBlue, 0)
    Call .BorderStyle(, , , , , , 33, 6, 6, 32)
    Call .LegendTableStyle(, , 25, 10, , , 14408703, 14408703)
    Call .SelectYaxis
    Call .AxisTitleStyle("First x-axis", , , 0)
    Call .NewDataSet("First axis Data") 'Start a new data set on the graph
    For i = 1 To 18 'Add some data points to the graph
      X = 100 + i
      Y = 100 + Sqr(i) + 2 * Rnd
      Call .AddDataPoint(X, Y)
    Next i
    
    Call .NewXAxis("Second x-Axis")
    Call .NewYAxis("Second y-Axis")
    Call .NewDataSet("Second axis Data") 'Start a new data set on the graph
    For i = 1 To 18 'Add some data points to the graph
      X = 50 + i
      Y = 80 + Sqr(i) + 2 * Rnd
      Call .AddDataPoint(X, Y)
    Next i
    
    Call .NewXAxis("Third x-Axis")
    Call .NewYAxis("Third y-Axis")
    Call .NewDataSet("Third axis Data") 'Start a new data set on the graph
    For i = 1 To 18 'Add some data points to the graph
      X = 10 + i
      Y = 60 + Sqr(i) + 2 * Rnd
      Call .AddDataPoint(X, Y)
    Next i
    
    Call .Refresh 'Always end with "Refresh"
  End With
End Sub

Public Sub Demo12(ecGraph1 As ecGraph)
  'Log scales, data points, and math functions
  Dim MathFunc$, i, rr, r As Double, X As Double, Y As Double
  With ecGraph1
    Call .Reset 'Always call "Reset" first to clear the page
    
    'Start a new graph on the page..
    Call .NewGraph("Log scales, data points, and math functions")
    Call .GraphTitleStyle(, "bold")
    Call .PlotAreaColors(ecLavender)
    Call .LegendTableStyle(, , 50, 64)
    Call .AxisStyle(, , True)
    Call .AxisGridStyle(ecLightGrey, ecLightGrey, True, True)
    Call .AxisLabelStyle("bold")
    Call .AxisTitleStyle("Particle size, um", "bold")
    Call .SelectYaxis
    Call .AxisStyle(, , True)
    Call .AxisGridStyle(ecLightGrey, ecLightGrey, True, True)
    Call .AxisLabelStyle("bold", , -1)
    Call .AxisTitleStyle("Specific Rate, 1/min", "bold")
    
    'Add a math function..
    MathFunc$ = "x/(1+(x/100)^2.4)*(1+(x/2000)^3.2)"
    Call .NewDataSet("Model:  y = x/(1+(x/a)^b)*(1+(x/c)^d)", True)
    Call .AddMathFunc(MathFunc$)
    Call .DataLine(ecGray, 2)
    
    'Add a math function..
    MathFunc$ = "x/(1+(x/600)^2.5)*(1+(x/18000)^2.5)/4"
    Call .NewDataSet("Simulated:  y = " + MathFunc$, False)
    Call .AddMathFunc(MathFunc$)
    Call .DataLine(ecGray, 2)
    
    'Add a math function..
    MathFunc$ = "x/(1+(x/3000)^2.5)/14"
    Call .NewDataSet("Simulated:  y = " + MathFunc$, False)
    Call .AddMathFunc(MathFunc$)
    Call .DataLine(ecGray, 2)
    
    'Start a new data set on the graph, and add random points..
    Call .NewDataSet("a. Experimental:  50 mm media")
    Call .SymbolStyle(3, 1.6, ecBlue, ecBlack, 1, , , , , False)
    Call .DataLine(, 0, 0)
    X = 0.6: r = 0.2
    For i = 1 To 31
      X = X * Sqr(2)
      Y = X / (1 + (X / 100) ^ 2.4) * (1 + (X / 2000) ^ 3.2) * ((1 - r) + 2 * r * Rnd)
      Call .AddDataPoint(X, Y, Y * r)
    Next i
    .BarShadowColor = ecGray '(used here for error bar color)
    
    'Start a new data set on the graph, and add random points..
    Call .NewDataSet("b. Experimental:  75 mm media")
    Call .SymbolStyle(, 1.6, ecRed, ecBlack, 1, , , , , False)
    X = 0.6
    For i = 1 To 31
      X = X * Sqr(2)
      Y = X / (1 + (X / 600) ^ 2.5) * (1 + (X / 18000) ^ 2.5) * ((1 - r) + 2 * r * Rnd) / 4
      Call .AddDataPoint(X, Y, Y * r)
    Next i
    
    'Start a new data set on the graph, and add random points..
    Call .NewDataSet("c. Experimental:  100 mm media")
    Call .SymbolStyle(, 2.2, vbGreen, ecBlack, 1, , , , , False)
    X = 0.6
    For i = 1 To 31
      X = X * Sqr(2)
      Y = X / (1 + (X / 3000) ^ 2.5) * ((1 - r) + 2 * r * Rnd) / 14
      Call .AddDataPoint(X, Y, Y * r)
    Next i
    
    Call .Refresh 'Always end with "Refresh"
  End With
End Sub


